#
# spec file for package libvterm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 0
Name:           libvterm
Version:        0~bzr696
Release:        lp151.2.2
Summary:        An abstract library implementation of a VT220/xterm/ECMA-48 terminal emulator
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://launchpad.net/libvterm
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
An abstract C99 library which implements a VT220 or xterm-like terminal
emulator.

%package -n %{name}%{sover}
Summary:        Shared library package of libvterm
Group:          System/Libraries

%description -n %{name}%{sover}
An abstract C99 library which implements a VT220 or xterm-like
terminal emulator. It does not use any particular graphics toolkit or
output system. Instead, it invokes callback function pointers that
its embedding program should provide it to draw on its behalf.

%package devel
Summary:        Development files of libvterm
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
This package contains the development files of libvterm.

%package tools
Summary:        Tools for libvterm
Group:          System/Console

%description tools
This package contains tools for libvterm.

%prep
%setup -q

%build
make PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     %{?_smp_mflags}

%install
make PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     DESTDIR=%{buildroot} \
     install

# Remove libtool files.
find %{buildroot} -type f -name "*.la" -delete -print

# Remove static library file.
rm -vf %{buildroot}%{_libdir}/%{name}.a

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root)
%doc LICENSE
%{_libdir}/%{name}.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/vterm*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/vterm.pc

%files tools
%defattr(-,root,root)
%{_bindir}/unterm
%{_bindir}/vterm-ctrl
%{_bindir}/vterm-dump

%changelog
* Sun May 28 2017 ronisbr@gmail.com
- Run spec-cleaner.
- Fix `libvterm.changes` indentation.
* Sat May 27 2017 bwiedemann@suse.com
- Version bump to 0~bzr696.
  Changelog:
  * Add S8C1T control support to vterm-ctrl
  * Implement querying of cursor shape in vterm-ctrl
  * Remember to document ST in doc/seqs.txt
  * Adjust linebreaking of 'break' statements to avoid gcc
    warnings of misleading indentation
  * Implement DECRQSS on SGR when set to RGB8 palette colours
  * Reset the pen between independent tests of DECRQSS on SGR
  * Bugfix for disabling mouse mode
  * Ensure stdin's ICANON mode is restored even if vterm-ctrl
    exits on error
  * Initialise mouse state at VTermState creation rather than as
    a side-effect of DECSM 100{0,2,3} - fixes LP1640917
  * Pull VTermScreenCell.attrs out to its own named type
  * Merge lp:~jamessan/libvterm/reproducibility (#307773,
    boo#1041090)
* Thu Aug 25 2016 ronisbr@gmail.com
- Version bump to 0~bzr684.
  Changelog:
  * Avoid "\e" because some C compilers don't like it
  * Don't use wchar_t in unicode.c as it might not be big enough
  * Remember to pass unicode codepoints in uint32_t rather than
    int
* Sat Apr  9 2016 ronisbr@gmail.com
- Version bump to 0~bzr681.
  Changelog:
  * Bugfix(?) for SunOS (thanks DominoTree -
    https://github.com/neovim/libvterm/pull/1/files)
  * (Alt-)Ctrl-Space should encode as (\e)\0
* Sat Dec  5 2015 jengelh@inai.de
- Move description from main part to shlib part, since this will be
  the one that always gets installed.
* Sat Dec  5 2015 ronisbr@gmail.com
- Remove unnecessary dependency from libvterm-tool.
* Sat Dec  5 2015 ronisbr@gmail.com
- Remove libtool files.
- Fix groups for libvterm, libvterm0, and libvterm-tools.
- Change package compression from .tar.gz to .tar.xz.
- Change %%{soname} to %%{sover}.
* Sat Dec  5 2015 ronisbr@gmail.com
- Change package name to libvterm.
* Wed Dec  2 2015 ronisbr@gmail.com
- Initial version based on home:gmc137:neovim/libvterm.
- Version bump to 0~bzr679.
- Change package version scheme to match openSUSE's guidelines.
- Clean spec file.
- Drop obsolete patch libvterm.optflags.patch.
